# Ebook UNASUS


> Ambiente de desenvolvimento e Ebook modelo para UNASUS

## Componentes

- [LTI - Sistema de integração de recursos educacionais.](#lti)
- [Desenvolvimento - Processo de desenvolvimento e integração contínua de recursos educacionais.](#desenvolvimento)
- [Ebook - Ebook Modelo.](#ebook)
- [CLI - Interface de linha de comando para auxílio de desenvolvimento.](#cli)


### LTI

Todos os recursos educacionais da unasus são integrados ao SAITEAVA através do protocolo [LTI](https://www.imsglobal.org/activity/learning-tools-interoperability), que permite que esses recursos hospedadas no servidor de recursos da UNASUS (Repocurso) sejam utilizadas como ferramentas externas e possam não somente ter acesso à informações sobre o aluno mas também enviar notas à plataforma.

#### Sistema LTI-UNASUS

O sistema responsável pela implementação do protocolo LTI e pelo armazenamento das informações levantadas foi construído utilizando o framework [LTIJS](https://cvmcosta.me/ltijs/#/), cuja documentação possui informações úteis para a manutenção do sistema da UNASUS. 

- O código do sistema pode ser encontrado no repositório [moodle/lti](http://git.unasus.ufma.br/moodle-lti/lti).

- O projeto [moodle/lti](http://git.unasus.ufma.br/moodle-lti/lti) está configurado com [Integração Contínua](https://aws.amazon.com/pt/devops/continuous-integration/), qualquer commit realizado ao **branch master** que contenha alterações no arquivo **index.js** engatilha o processo de integração que realiza um hot reload da aplicação aplicando todas as alterações de maneira rápida.

#### Configurando o sistema LTI-UNASUS em um AVA

A configuração do sistema LTI-UNASUS em qualquer AVA consiste 3 etapas:

- Registro do LTI-UNASUS no AVA;
- Registro do AVA no LTI-UNASUS;
- Configuração de recursos educacionais.


**Registrando o LTI-UNASUS no AVA:**

Como administrador acesse: 

- **Administração do site > Plugins > Gerenciar ferramentas > Configurar uma ferramenta manualmente**

> Plugins

<div align="center">
	<br>
	<img width="500" src="readme_assets/plugin.png"></img></a>
  <br>
</div>

> Gerenciar ferramentas

<div align="center">
	<br>
	<img width="500" src="readme_assets/managetool.png"></img></a>
  <br>
</div>


> Menu de registro

<div align="center">
	<br>
	<img width="500" src="readme_assets/registro.png"></img></a>
  <br>
</div>


Na tela de registro, mude a **Versão do LTI** para a **LTI 1.3**

<div align="center">
	<br>
	<img width="500" src="readme_assets/ltiversion.png"></img></a>
  <br>
</div>


Preencha o campo **Nome da ferramenta** com um nome adequado.

No campo **Url da ferramenta** coloque o endereço do sistema LTI-UNASUS (atualmente https://lti.saiteava.org).

Com a versão do LTI em 1.3, novas opções se tornam visíveis:

<div align="center">
	<br>
	<img width="500" src="readme_assets/ltiadvantage.png"></img></a>
  <br>
</div>

Mude o tipo de chave pública para Keyset Url e preencha o campo **Public Keyset** com o endereço de chaves do sistema LTI-UNASUS (atualmente https://lti.saiteava.org):

<div align="center">
	<br>
	<img width="500" src="readme_assets/keys.png"></img></a>
  <br>
</div>


Agora, preencha os campos **Iniciar URL de login** e **URl(s) de redirecionamento**:

O primeiro campo deverá conter o endereço do sistema LTI-UNASUS seguido de **'/login'** e o segundo deverá conter o mesmo valor do campo **Url da ferramenta**:

<div align="center">
	<br>
	<img width="500" src="readme_assets/loginredir.png"></img></a>
  <br>
</div>

Em seguida você deve acessar a área de **Serviços** e selecionar em todos os campos, a opção que indique que o serviço deverá ser utilizado (normalmente a ultima opção em cada caixa de seleção):

<div align="center">
	<br>
	<img width="500" src="readme_assets/services.png"></img></a>
  <br>
</div>

Agora você já pode salvar a nova ferramenta.

Retornando ao menu anterior, você verá a sua ferramenta registrada. E clicando no ícone (as vezes invisível) à esquerda da engrenagem, você poderá ver todas as informações da ferramenta e plataforma:

<div align="center">
	<br>
	<img width="500" src="readme_assets/newtool.png"></img></a>
  <br>
</div>

Ex informações:

<div align="center">
	<br>
	<img width="500" src="readme_assets/toolinfo.png"></img></a>
  <br>
</div>


***Você deverá salvar o ClientId(Id do cliente) para que ele seja utilizado no cadastro do AVA no LTI-UNASUS.***

**Registrando o AVA no LTI-UNASUS:**

Registrar um novo AVA no sistema LTI-UNASUS é simples, basta clonar o código do repositório [moodle/lti](http://git.unasus.ufma.br/moodle-lti/lti) e adicionar o endereço completo do novo AVA, o nome do AVA e o ClientId gerado pelo Moodle no array de plataformas que devem ser registradas sempre que houver um hot reload:

<div align="center">
	<br>
	<img width="500" src="readme_assets/platforms.png"></img></a>
  <br>
</div>

Assim que o commit for realizado, a pipeline responsável irá efetuar um hot reload e as novas plataformas presentes no array serão registradas.

**Configurando recursos educacionais:**

Ao adicionar uma nova atividade em um curso, selecione a opção **Ferramenta externa**:

<div align="center">
	<br>
	<img width="400" src="readme_assets/add_activity.png"></img></a>
  <br>
</div>

Na tela de edição insira um nome e descrição para a atividade e no campo **Ferramenta pré-configurada** selecione a ferramenta LTI-UNASUS:

<div align="center">
	<br>
	<img width="500" src="readme_assets/configure_activity.png"></img></a>
  <br>
</div>

Em seguida, selecione o método de exibição (Incorporado sem blocos) e preencha o campo **Parâmetros customizados** com as informações:

- resourceurl - Url completa do recurso no repocurso.
- resourcename - Nome do recurso.

<div align="center">
	<br>
	<img width="500" src="readme_assets/custom_param.png"></img></a>
  <br>
</div>

Agora você pode realizar as configurações adicionais de nota e acesso e salvar a nova atividade.

### Desenvolvimento

O processo de desenvolvimento de recursos educacionais do ponto de vista da TI começa com o envio de um documento que determina o conteúdo, aparência e funcionalidades do novo recurso.

Durante todo o fluxo, o livro passa por uma variedade de etapas de etapas de desenvolvimento todas dentro do seguinte modelo:

<div align="center">
	<br>
	<img width="700" src="readme_assets/fluxo.png"></img></a>
  <br>
</div>

- 1 - O DI envia um powerpoint ou pdf descrevendo o recurso que deverá ser criado.
- 2 - O colaborador da TI desenvolve o que está sendo pedido.
- 3 - O QA valida o que foi desenvolvido para verificar se está de acordo com o que foi pedido.
- 4 - Se o recurso for aprovado na validação do QA, prossegue-se para a etapa 5. Se não foi aprovado, retorna-se para a etapa 2 para que as correções sejam realizadas.
- 5 - O DI realiza revisões adicionais, essa etapa na realidade consiste de três revisões específicas (Revisão inicial, Revisão textual e Revisão de protótipo final) cada uma requisitando novas alterações. Ao final da Revisão de protótipo final, caso o livro seja aprovado, é realizada a entrega final do recurso, no SAITEAVA e SAITESTORE (Caso seja um EBOOK).

Esse fluxo de desenvolvimento, na prática, faz uso do [Gitflow](https://imasters.com.br/agile/fluxo-de-desenvolvimento-com-gitflow) para organizar e documentar cada etapa de desenvolvimento, assim como possíveis micro alterações após o lançamento do recurso:

<div align="center">
	<br>
	<img width="600" src="readme_assets/gitflow.png"></img></a>
  <br>
  <sub>Exemplo Gitflow</sub>
  <br>
</div>

- Ao receber o pdf do recurso, é criado o projeto no GitLab com uma issue inicial `Criação de recurso: NOME DO RECURSO` atribuída ao colaborador responsável pelo desenvolvimento. Essa issue deve ser dada como resolvida somente no momento de entrega final do recurso.

- Deve ser criada uma branch `develop` que será utilizada para validações realizadas pelo DI. A partir dessa branch serão criadas branches de features referentes a cada etapa do desenvolvimento, por exemplo uma branch `dev/revisaotextual`.

- Cada etapa de desenvolvimento, desde as principais até micro alterações, deve gerar uma issue descrevendo a tarefa à ser realizada e atribuida à um colaborador.

- Após o cumprimento de uma tarefa e a realização de um commit ligando essa tarefa a uma issue aberta, o QA deverá validar o recurso na branch específica daquela tarefa. Caso o recurso seja aprovado, a issue referente deverá ser fechada, e o branch mergeado com a branch develop.

- Cada merge bem sucedido com a branch develop aciona uma pipeline que realiza a submissão do recurso para o repocurso e gera um link que pode ser enviado para o DI para validação.

- Após a etapa de Revisão de protótivo final, caso o recurso seja aprovado, a issue inicial deverá ser fechada e a branch develop deverá ser mergeada com a branch Master, isso acionará uma pipeline submetendo mais uma vez o recurso para o repocurso, mas dessa vez gerando um link de distribuição do recurso.

- Após o lançamento do recurso, pequenas alterações deveram ser tratadas como HotFixes. Cada HotFix deve resultar em uma issue e na criação de uma branch a partir da Master, onde as modificações deveram ser realizadas.

#### Modelo de commit

Todo commit efetuado deve seguir o [padrão Karma de commits](http://karma-runner.github.io/3.0/dev/git-commit-msg.html) que segue a seguinte estrutura: 

```
<tipo>(<escopo>): <descrição breve>

<corpo>

<issue relacionado>
```

Exemplo: 

```
fix(CaixaModal): Alterando a posição do Modal na página.

Modal agora abre centralizado e se reajusta sempre que 
há um redimencionamento na página.

Fixes #15
```

### Ebook

Os ebooks da UNASUS foram construídos utilizando [ReactJs](https://reactjs.org/) e o conceito de componentização para facilitar ao máximo o processo de desenvolvimento de novos ebooks a partir do Ebook Modelo existente, cada efeito utilizado foi transformado em componente para que possam ser reutilizados de maneira rápida.

Ex: 

``` javascript
import CaixaColorida from '../components/CaixaColorida'
// ... // 
<CaixaColorida Content='Lorem ipsum dolor sit amet.' />
```

O código livros está organizados em 4 pastas principais, **core, components, local e pages**:

<div align="center">
	<br>
	<img width="200" src="readme_assets/folderstruct.png"></img></a>
  <br>
  <sub>Estrutura de pastas</sub>
  <br>
</div>

As pastas **core e components** só podem ser tocadas no Ebook Modelo, nelas estão contidos os códigos básicos da estrutura e componentes dos ebooks, portanto qualqer modificação nessas pastas pode destruir a consistência entre os recursos.

Para que as modificações realizadas na estrutura do Ebook Modelo sejam propagadas, existem uma CLI e uma pipeline que cuidam de realizar o update dos demais ebooks.

A pasta **local** contém arquivos de configuração pertinentes à cada ebook específico, controlando cor do ebook, título, número de páginas, entre outros.

A pasta **pages** é onde a maior parte do desenvolvimento diário ocorre, é onde se encontram o código de cada página do ebook.



### CLI


Para auxilir no desevolvimento, foi criada uma CLI que 