import React from 'react'
import styled from 'styled-components'

import CssBaseline from '@material-ui/core/CssBaseline'
import Box from '@material-ui/core/Box'
import { UAParser } from 'ua-parser-js'
import { withSnackbar } from 'notistack'

import Drawer from './components/Drawer'
import ProgressBar from './components/ProgressBar'
/* import Comments from './components/Comments' */
import Marker from './components/Marker'
import ReadBook from './components/ReadBook'
import Nav from './components/Nav'
import Tooltip from './components/Tooltip'
import RotatePhone from './components/RotatePhone'
import * as Pages from './pages/Pages'
// import './core/js/Logger'
import Storage from './core/js/Storage'

import $ from 'jquery'
import Swipe from 'react-easy-swipe'

import './core/css/style.scss'
import config from './local/js/config'

import { ltikey } from './core/js/LTI'

const parser = new UAParser(navigator.userAgent)
const device = parser.getDevice()

const Window = styled.div`
  width: 100%;
  height: 100%;
  background-color: ${config.BackgroundColor};
  p{
    font-size: ${props => props.sizeP + 'px'};
  }
  h2{
    font-size: ${props => props.sizeH2 + 'px'};
  }
  .Ebook{
    display: flex;
    position: relative;
    background-color: ${config.EbookColor};
    
    height: 100%;
    z-index: 2;
    flex-direction: column;
    justify-content: center; 
    width: 100vh; 
    @media (max-width: 100vh) {
      width: 100% !important;
    }
    .content{
      height: ${props => props.sizeContent + 'px'};
    }
  }
  .swipe{
    display: contents
  }
  
  
`
const Frame = styled.div`
  width: 100%;
  height: 100%;
  
`
const FrameHeader = styled.div`
  position: absolute;
  top: 0;
  height: 7%;
  width: 100%;
  background-color: ${config.FrameColor};
`
const FrameFooter = styled.div`
  position: absolute;
  bottom: 0;
  height: 2%;
  width: 100%;
  background-color: ${config.FrameColor};
`
const EbookHeader = styled.div`
  height: 13%;
  width: 100%;
  position: relative; 
  @media (min-width: 150vh) {
    height: 7%;
  }
`
const EbookFooter = styled.div`
  height: 2%;
  width: 100%;
`
const BookTitle = styled.div`
  display:  inline;
  line-height: normal;
  font-size: ${props => props.sizeTitle + 'px'};
  color: white;
  margin-right: 2.5vh;
  @media (max-width: 100vh) {
    font-size: 1.9vh !important
  }
`
const TitleDiv = styled.div`
  width: 100%;
  height:50%;
  padding-left: 5%;
  padding-right: 5%;
  position: relative;
  margin: auto;
  display: flex;
  background-color: ${config.TitleColor};
`
const NavDiv = styled.div`
  width: 95%;
  height:50%;
  position: relative;
  display: flex;
  margin: auto;
`

const EbookContent = styled.div`
  background-color: white;
  flex: 1;
  width: 100%;
  border-radius: 2%;
  padding: 2vh;
  position: relative;
  overflow: hidden;
`
const HeaderNavDesktop = styled.div`
  position: relative;
  width: 95%;
  height: 100%;
  margin: auto;
  display:none;
  @media (min-width:150vh) {
    display: flex;
  }

`
const HeaderNavMobile = styled.div`
  position: relative;
  width: 90%;
  height: 100%;
  margin: auto;
  display: inline;
  @media (min-width:150vh) {
    display: none;
  }
`

const Background = styled.div`
  position: absolute;
  top: 0;
  left:0;
  width: 100%;
  height: 100%;
  background-color: ${config.BackgroundColor};
  @media (min-width:150vh) {
    display: none;
  }
`
const BackgroundHeader = styled.div`
  position: absolute;
  top: 0;
  height: 2%;
  width: 100%;
  background-color: ${config.FrameColor};
`

const ltik = ltikey()

const orientation = () => {
  let orientation
  if (window.orientation !== undefined) orientation = window.orientation
  else  if (screen.orientation !== undefined) orientation = screen.orientation.angle // eslint-disable-line
  else {
    return window.innerHeight > window.innerWidth ? 'portrait' : 'landscape'
  }
  console.log(device)
  if (orientation >= 90 || orientation === -90) {
    if (device.type !== undefined) return 'landscape'
  }
  return 'portrait'
}

class App extends React.Component {
  constructor (props) {
    super(props)

    this.state = {
      curPage: 1,
      curMaxPage: 1,
      maxPage: config.Pages,
      page: Pages['Page1'],
      orientation: $(window).width() < config.MobileBreakpoint ? orientation() : 'desktop'
    }

    if (ltik) {
      Storage.retrieveCurMaxPage().then(pageInfo => {
        if (pageInfo) {
          this.setState({
            curPage: pageInfo.curPage,
            curMaxPage: pageInfo.maxPage,
            page: Pages['Page' + pageInfo.curPage]

          })
          $(document).trigger('updatePage', [pageInfo.curPage])
          $(document).trigger('updateMaxPage', [pageInfo.maxPage])
          $(document).trigger('updateMenu', [pageInfo.maxPage, pageInfo.curPage])
        }
      })
    }

    $(document).on('changePage', (e, page, menu, subMenu, code) => {
      this.changePage(page, menu, subMenu, code)
    })
    $(document).on('prevPage', (e) => {
      this.changePage(this.state.curPage - 1)
    })
    $(document).on('nextPage', (e) => {
      this.changePage(this.state.curPage + 1)
    })

    $(document).on('errorMessage', (e, message) => {
      this.props.enqueueSnackbar(message, { variant: 'error' })
    })

    $(document).on('successMessage', (e, message) => {
      this.props.enqueueSnackbar(message, { variant: 'success' })
    })
    // Arrow keys
    $(document).keyup((event) => {
      // seta direita
      if (event.keyCode === 39) $(document).trigger('nextPage')

      // seta esquerda
      if (event.keyCode === 37) $(document).trigger('prevPage')
    })
  }

  componentDidMount () {
    $(window).on('resize orientationchange', () => {
      this.setState({
        orientation: $(window).width() < config.MobileBreakpoint ? orientation() : 'desktop'
      })
      this.calculateFont()
    })
    $('.MuiIconButton-label').css('width', '100%')
    $('.MuiIconButton-label').css('height', '100%')
  }

  calculateFont () {
    $('.Ebook').css('width', $(window).height())
    const f_p = ((2.3 / 100) * ($('.Ebook').width() * 0.94))
    $('p').css('font-size', f_p)
    const f_h2 = ((1.4 / 100) * ($('.Ebook').width() * 0.95)) + ((1.4 / 100) * $('.Ebook').height())
    $('h2').css('font-size', f_h2)
    const s_c = $(window).width() >= ($(window).height() + (50 / 100 * $(window).height())) ? ((83 / 100) * $(window).height()) : ((77 / 100) * $(window).height())
    $('.content').css('height', s_c)
    const f_t = ((1.1 / 100) * ($('.Ebook').width() * 0.95)) + ((1.1 / 100) * $('.Ebook').height())
    $('.bookTitle').css('font-size', f_t)
  }

  changePage (page, menu, subMenu, code) {
    if (page <= this.state.maxPage && page >= 1) {
      let curMaxPage = this.state.curMaxPage
      if (this.state.curPage + 1 === page && curMaxPage === this.state.curPage) {
        this.setState({ curMaxPage: page })
        curMaxPage = page
      }
      if (this.state.curPage === 1 && page === 2) {
        $('.content').removeClass('capa')
      }
      let changeFont = false
      if ($('p').hasClass('change_font')) changeFont = $('p').css('font-size')
      this.setState({ curPage: page, page: Pages['Page' + page] })
      $(document).trigger('updatePage', [page, changeFont])
      $(document).ready(() => $('.noswipe').find('*').addClass('noswipe'))
      $(document).trigger('updateMaxPage', [curMaxPage])
      $(document).trigger('updateMenu', [curMaxPage, page, menu, subMenu, code])
      if (ltik) Storage.saveCurMaxPage(page, curMaxPage)
      $(document).trigger('log', [{ type: 'change_page', other: { page: page } }])
    }
  }

  swipeRight (obj1, obj2) {
    if ($(window).width() >= config.MobileBreakpoint || $(obj2.target).hasClass('noswipe')) return
    $(document).trigger('prevPage')
  }

  swipeLeft (obj1, obj2) {
    if ($(window).width() >= config.MobileBreakpoint || $(obj2.target).hasClass('noswipe')) return
    $(document).trigger('nextPage')
  }

  render () {
    if (this.state.orientation === 'landscape') {
      return <RotatePhone />
    } else {
      return (
        <Window sizeP={((2.3 / 100) * ((94 / 100) * $(window).height()))} sizeH2={((1.4 / 100) * ((95 / 100) * $(window).height())) + ((1.4 / 100) * $(window).height())} sizeContent={$(window).width() >= ($(window).height() + (50 / 100 * $(window).height())) ? ((83 / 100) * $(window).height()) : ((77 / 100) * $(window).height())}>
          <CssBaseline />
          <Frame className='main mainFrame d-flex flex-column align-items-center justify-content-center'>
            <FrameHeader className='main d-flex  align-items-center noselect'>
              <Tooltip Title='Menu' menu noP Content={<Drawer color={config.EbookColor} sizeText={((1 / 100) * ((95 / 100) * $(window).height())) + ((1 / 100) * $(window).height())} page={this.state.curPage} maxPage={this.state.curMaxPage} Code='1' />} />
              {/* <Comments/> */}
              {ltik ? (<Marker page={this.state.curPage} />) : ('') }
              <Tooltip Title='Áudio' noP Content={<ReadBook />} />
            </FrameHeader>
            <Background>
              <BackgroundHeader />
            </Background>
            <Box className='Ebook' boxShadow={7}>
              <EbookHeader className='noselect'>

                <HeaderNavDesktop className='main align-items-center justify-content-between'>
                  <BookTitle className='align-middle bookTitle' sizeTitle={((1.1 / 100) * ((95 / 100) * $(window).height())) + ((1.1 / 100) * $(window).height())}>{config.ModuleName}</BookTitle>
                  <Nav curPage={this.state.curPage} maxPage={this.state.maxPage} changePage={this.changePage} />
                </HeaderNavDesktop>

                <HeaderNavMobile className='mobile_header'>
                  <TitleDiv className='main align-items-center justify-content-between'>
                    <BookTitle className='align-middle'>{config.ModuleName}</BookTitle>
                  </TitleDiv>

                  <NavDiv className='main align-items-center justify-content-between'>
                    <div className='d-flex'>
                      <Drawer color={config.EbookColor} sizeText={((1 / 100) * ((95 / 100) * $(window).height())) + ((1 / 100) * $(window).height())} page={this.state.curPage} maxPage={this.state.curMaxPage} Code='2' />
                      {/* <Comments/> */}
                      {ltik ? (<Marker page={this.state.curPage} />) : ('') }
                      <ReadBook />
                    </div>
                    <Nav curPage={this.state.curPage} maxPage={this.state.maxPage} changePage={this.changePage} />
                  </NavDiv>
                </HeaderNavMobile>

              </EbookHeader>
              <Swipe className='swipe' onSwipeRight={this.swipeRight} onSwipeLeft={this.swipeLeft} tolerance={100}>
                <EbookContent>
                  <ProgressBar color={config.SecondaryBarColor} curPage={this.state.curMaxPage} maxPage={this.state.maxPage} />
                  <this.state.page />
                </EbookContent>
              </Swipe>
              <EbookFooter />

            </Box>
            <FrameFooter />
          </Frame>

        </Window>
      )
    }
  }
}

export default withSnackbar(App)
