import React from 'react'
import PropTypes from 'prop-types'
import { makeStyles } from '@material-ui/core/styles'
import AppBar from '@material-ui/core/AppBar'
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab'
import Typography from '@material-ui/core/Typography'
import Box from '@material-ui/core/Box'
import styled from 'styled-components'
import $ from 'jquery'
import config from '../local/js/config'
import SwipeableViews from 'react-swipeable-views'

const StyledDiv = styled.div`
  .MuiButtonBase-root, .MuiTabs-scrollButtonsDesktop{
    background-color: ${config.SecondaryColor};
    height: 100%;
    min-height: 0;
  }
  .MuiTab-textColorPrimary.Mui-selected{
    color: white;
    background-color: ${config.PrimaryColor};
    padding: 0;
    margin: 0;
  }
  .MuiTabs-indicator{
    background-color: white;
    height: 0.4vh;
  }
  .MuiTab-textColorPrimary{
    color: #000000a8;
  }
  .MuiTypography-root{
    border: solid 2px ${config.SecondaryColor};
    font-size: ${props => props.fontText + 'px'};
    min-height: 10vh;
    @media (max-width: 100vh) {
      font-size: font-size: calc(1.4vw + 1.4vh) !important;
    }
    position: relative;
    ul { padding: 1%; }
  }
  .MuiSvgIcon-root{
    color: white;
    font-size: calc(1vw + 1vh);
  }
  .MuiTab-wrapper{ 
    font-size: ${props => props.fontButtonText + 'px'};
    @media (max-width: 100vh) {
      font-size: calc(1vw + 1vh) !important;
    }
  }
  .MuiTabs-flexContainer{
    position: relative;
    height: 100%;
    background-color: ${config.SecondaryColor};
  }
  .MuiTab-root{
    max-width: unset;
    min-width: unset;
    padding: 0;
    margin: 0;
    width: 30%;
    margin-left: -2px;
    margin-right: -2px;
  }
  .MuiTabs-root{
    min-height: 5vh;
    max-height: 6vh;
    height: auto;
    margin-left: -2px;
    margin-right: -2px;
  }
  .MuiTabs-scrollButtons{
    width: 8%;
    height: auto;
  }
  .MuiBox-root{
    padding: 3vh;
    padding-top: 1.5vh;
    padding-bottom: 1.5vh
  }
  .MuiAppBar-colorDefault {
    background-color: ${config.SecondaryColor};
  }
`

function TabPanel (props) {
  const { children, value, index, ...other } = props

  return (
    <Typography
      component='div'
      role='tabpanel'
      hidden={value !== index}
      id={`scrollable-auto-tabpanel-${index}`}
      aria-labelledby={`scrollable-auto-tab-${index}`}
      {...other}
    >
      <Box p={3}>{children}</Box>
    </Typography>
  )
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired
}

function a11yProps (index) {
  return {
    id: `scrollable-auto-tab-${index}`,
    'aria-controls': `scrollable-auto-tabpanel-${index}`
  }
}

const useStyles = makeStyles(theme => ({
  root: {
    flexGrow: 1,
    width: '100%',
    backgroundColor: theme.palette.background.paper
  }
}))

export default function ScrollableTabsButtonAuto (props) {
  const classes = useStyles()
  const [value, setValue] = React.useState(0)

  $(window).resize(() => {
    calculateFont()
  })

  function calculateFont () {
    const f_txt = ((2.3 / 100) * $('.Ebook').width())
    $('.MuiTypography-root').css('font-size', f_txt)
    const f_btntxt = ((0.8 / 100) * $('.Ebook').width()) + ((0.8 / 100) * $('.Ebook').height())
    $('.MuiTab-wrapper').css('font-size', f_btntxt)
  }

  function handleChange (event, newValue) {
    setValue(newValue)
  }

  function handleChangeIndex (index) {
    setValue(index)
  }

  return (
    <StyledDiv className={classes.root + ' noswipe caixa caixa-tabs'} fontText={((2.3 / 100) * ((94 / 100) * $(window).height()))} fontButtonText={((0.9 / 100) * ((96 / 100) * $(window).height())) + ((0.9 / 100) * $(window).height())}>
      <AppBar position='static' color='default'>
        <Tabs
          value={value}
          onChange={handleChange}
          indicatorColor='primary'
          textColor='primary'
          variant='scrollable'
          scrollButtons='auto'
          aria-label='scrollable auto tabs example'
        >
          {props.Content.map((value, index) => {
            return <Tab label={value.header} {...a11yProps(index)} />
          })}

        </Tabs>
      </AppBar>
      {props.swipe
        ? <SwipeableViews
          axis='x'
          index={value}
          onChangeIndex={handleChangeIndex}
        >
          {props.Content.map((valor, index) => {
            return <TabPanel value={value} index={index}>
              {valor.content}
            </TabPanel>
          })}
        </SwipeableViews>
        : <>{props.Content.map((valor, index) => {
          return <TabPanel value={value} index={index}>
            {valor.content}
          </TabPanel>
        })}</ >}
    </StyledDiv>
  )
}
