import React, { useState } from 'react'

import styled from 'styled-components'
import Select from '@material-ui/core/Select'
import MenuItem from '@material-ui/core/MenuItem'
import FormControl from '@material-ui/core/FormControl'
import config from '../local/js/config'

// Styling
const StyledDiv = styled.div`
  width: 97%;
  margin: auto;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  .MuiOutlinedInput-root.Mui-focused .MuiOutlinedInput-notchedOutline {
    border: none !important;
  }
  .MuiOutlinedInput-root:hover .MuiOutlinedInput-notchedOutline{
    border: none !important
  }
  
  @media (max-width: 100vh) {
      width: 98%;
  }
  p{
    margin-bottom: 0 !important;
  }
  .selectionBox{
    width: 100%;
    background-color: ${config.SecondaryColor};
    div{
      border-top-left-radius: 1vh;
      border-top-right-radius: 1vh;
      border-color: transparent !important;
      box-shadow: none !important;
      &:focus {
          outline: none;
      }
    }
    border-top-left-radius: 1vh;
    border-top-right-radius: 1vh;
    border-color: transparent !important;
    box-shadow: none !important;
    
    &:focus {
          outline: none;
      }
    p{
      color: white
    }
    .MuiSelect-iconOutlined{
      color: white;
    }
  }
  .imageBox{
    width: 100%;
    margin: auto;
    display: flex;
    align-items: center;
    position: relative;
    img{
      margin: auto;
      width: 100%;
    }
    .marker{
      transition: all 0.5s ease;
      position: absolute;
      width: 5vh;
      height: 5vh;
      display:flex;
      color: white;
      border-radius: 50%;
      align-items: center;
      justify-content: center;
      background-color: blue;
      p{
        margin-bottom: 0 !important
      }
    }
  }
  .textBox{
    width: 100%;
    margin: auto;
    padding: 1vh;
    border: solid 0.2vh;
    border-radius: 1vh; 
    p{
      margin-bottom: 0 !important
    }
  }
  .caixa-sombreada-simples{
      transition: all 0.5s ease;
      height: auto;
      background-color: white;
      border-radius: 1vh;
      border-top-left-radius: 0;
      border-top-right-radius: 0;
      border: solid ${config.SecondaryColor};
      padding: 2vh;
      width: 100%;
      margin: auto;
      p{
          margin: 0;
      }
    }
`

export default function MarcacaoImagemConteudo (props) {
  const { Image, Content, Areas, Message, Default } = props
  const [panel, setPanel] = useState(Default === undefined ? -1 : Default)

  const handleChange = e => {
    setPanel(e.target.value)
  }

  return (
    <StyledDiv>
      <FormControl className='selectionBox' variant='outlined'>
        <Select
          id='shift'
          name='shift'
          autoComplete='shift'
          value={panel}
          required
          onChange={handleChange}
        >
          <MenuItem value={-1}><p>{Message}</p></MenuItem>
          {Areas.map((area, index) => (
            <MenuItem value={index}><p>{area}</p></MenuItem>
          ))}
        </Select>
      </FormControl>
      <div className='imageBox'>
        <img src={Image} />
        {(panel !== -1 && Image)
          ? <div className='marker pulse animated infinite' id={'marker' + (panel + 1)}><p>{(panel + 1)}</p></div>
          : <></>}
      </div>
      {panel !== -1
        ? <div className='animated fadeInDown faster caixa-sombreada-simples'><p>{Content[panel]}</p></div>
        : <></>}
    </StyledDiv>
  )
}
