import React from 'react'
import PropTypes from 'prop-types'
import { makeStyles } from '@material-ui/core/styles'
import AppBar from '@material-ui/core/AppBar'
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab'
import Typography from '@material-ui/core/Typography'
import Box from '@material-ui/core/Box'
import styled from 'styled-components'
import $ from 'jquery'
import config from '../local/js/config'
import SwipeableViews from 'react-swipeable-views'

const StyledDiv = styled.div`
  .MuiButtonBase-root, .MuiTabs-scrollButtonsDesktop{
    background-color: ${config.SecondaryColor};
    height: 100%;
    min-height: 0;
  }
  .MuiTab-textColorPrimary.Mui-selected{
    color: white;
    background-color: ${config.PrimaryColor};
    padding: 0;
    margin: 0;
  }
  .MuiTabs-indicator{
    background-color: white;
    height: 0.4vh;
  }
  .MuiTab-textColorPrimary{
    color: #000000a8;
  }
  .MuiTypography-root{
    border: none;
    font-size: ${props => props.fontText + 'px'};
    min-height: 10vh;
    @media (max-width: 100vh) {
      font-size: font-size: calc(1.4vw + 1.4vh) !important;
    }
    position: relative;
    ul { padding: 1%; }
  }
  .MuiSvgIcon-root{
    color: white;
    font-size: calc(1vw + 1vh);
  }
  .MuiTab-wrapper{ 
    font-size: ${props => props.fontButtonText + 'px'};
    @media (max-width: 100vh) {
      font-size: calc(1vw + 1vh) !important;
    }
  }
  .MuiTabs-flexContainer{
    position: relative;
    height: 100%;
    background-color: ${config.SecondaryColor};
  }
  .MuiTab-root{
    max-width: unset;
    min-width: unset;
    width: 33%;
    margin-left: -2px;
    margin-right: -2px;
  }
  .MuiTabs-root{
    min-height: 5vh;
    max-height: 6vh;
    height: auto;
    margin-left: -2px;
    margin-right: -2px;
  }
  .MuiTabs-scrollButtons{
    width: 10%;
    height: auto;
  }
  .MuiBox-root{
    padding: 0;
    width: 100%;
    height: 100%;
  }
  table{
    width: 100%;
    height: 100%;
    margin-top: 1vh;
    tr{
      border: solid 0.1vh lightgrey;
      display: flex;
      td.item{
        display: flex;
        align-items: center;
        justify-content: center;
        p{
          text-align: center;
          margin: 0;
          width: 100%;
          color: white;
        }
        background-color: ${config.PrimaryColor};
        width: 30%;
        height: auto;
        border-right: solid 0.1vh;
        padding: 2vh;
      }
      td.description{
        display: flex;
        flex: 1;
        align-items: center;
        padding: 1.5vh;
        max-height: 25vh;
        p{
          width: 100%;
          height: 100%;
          overflow: auto;
          margin: 0;
          ul{
            margin-left: 2.5vh;
          }
        }
      }
    }
  }
`

function TabPanel (props) {
  const { children, value, index, ...other } = props

  return (
    <Typography
      component='div'
      role='tabpanel'
      hidden={value !== index}
      id={`scrollable-auto-tabpanel-${index}`}
      aria-labelledby={`scrollable-auto-tab-${index}`}
      {...other}
    >
      <Box p={3}>{children}</Box>
    </Typography>
  )
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired
}

function a11yProps (index) {
  return {
    id: `scrollable-auto-tab-${index}`,
    'aria-controls': `scrollable-auto-tabpanel-${index}`
  }
}

const useStyles = makeStyles(theme => ({
  root: {
    flexGrow: 1,
    width: '100%',
    backgroundColor: theme.palette.background.paper
  }
}))

export default function ScrollableTabsButtonAuto (props) {
  const classes = useStyles()
  const [value, setValue] = React.useState(0)

  $(window).resize(() => {
    calculateFont()
  })

  function calculateFont () {
    const f_txt = ((2.3 / 100) * $('.Ebook').width())
    $('.MuiTypography-root').css('font-size', f_txt)
    const f_btntxt = ((0.8 / 100) * $('.Ebook').width()) + ((0.8 / 100) * $('.Ebook').height())
    $('.MuiTab-wrapper').css('font-size', f_btntxt)
  }

  function handleChange (event, newValue) {
    setValue(newValue)
  }
  function handleChangeIndex (index) {
    setValue(index)
  }
  return (
    <StyledDiv className={classes.root + ' noswipe caixa caixa-tabs'} fontText={((2.3 / 100) * ((96 / 100) * $(window).height()))} fontButtonText={((0.9 / 100) * ((96 / 100) * $(window).height())) + ((0.9 / 100) * $(window).height())}>
      <AppBar position='static' color='default'>
        <Tabs
          value={value}
          onChange={handleChange}
          indicatorColor='primary'
          textColor='primary'
          variant='scrollable'
          scrollButtons='auto'
          aria-label='scrollable auto tabs example'
        >
          {props.Content.map((tab, index) => {
            return <Tab label={tab.header} {...a11yProps(index)} />
          })}

        </Tabs>
      </AppBar>
      <SwipeableViews
        axis='x'
        index={value}
        onChangeIndex={handleChangeIndex}
      >
        {props.Content.map((tab, index) => {
          return <TabPanel value={value} index={index}>
            <table>
              {tab.content.map((row, index) => {
                return <tr>
                  <td className='item'><p><strong>{row.item}</strong></p></td>
                  <td className='description'><p>{row.description}</p></td>
                </tr>
              })}
            </table>
          </TabPanel>
        })}
      </SwipeableViews>
    </StyledDiv>
  )
}
