import React from 'react'
import { withStyles, makeStyles } from '@material-ui/core/styles'
import Table from '@material-ui/core/Table'
import TableBody from '@material-ui/core/TableBody'
import TableCell from '@material-ui/core/TableCell'
import TableContainer from '@material-ui/core/TableContainer'
import TableHead from '@material-ui/core/TableHead'
import TableRow from '@material-ui/core/TableRow'
import Paper from '@material-ui/core/Paper'
import config from '../local/js/config'

const StyledTableCell = withStyles((theme) => ({
  head: {
    backgroundColor: config.PrimaryColor,
    color: theme.palette.common.white,
    borderRight: 'solid white',
    '& p': {
      marginBottom: '0 !important',
      textAlign: 'center'
    }
  },
  body: {
    fontSize: 14
  }
}))(TableCell)

const StyledTableRow = withStyles((theme) => ({
  root: {
    backgroundColor: theme.palette.action.hover
  }
}))(TableRow)

const useStyles = makeStyles({
  table: {
    minWidth: 700
  },
  cell: {
    borderRight: 'solid white',
    '& p': {
      marginBottom: '0 !important'
    }
  }
})

export default function TabelaAnimadaSimples (props) {
  const classes = useStyles()
  const { Content, Headers } = props

  return (
    <TableContainer component={Paper} className='noswipe'>
      <Table className={classes.table} aria-label='customized table'>
        <TableHead>
          <TableRow>
            {Headers.map((header) => (
              <StyledTableCell align='center' className={'animated slideInLeft faster'} ><p>{header}</p></StyledTableCell>
            ))}
          </TableRow>
        </TableHead>
        <TableBody>
          {Content.map((row, index) => (
            <StyledTableRow className={'animated slideInLeft faster ' + ('delay-' + (index + 1) + 's')} key={'row' + index}>
              {Headers.map((header, index) => (
                <StyledTableCell className={classes.cell} align='left'><p>{row[index]}</p></StyledTableCell>
              ))}
            </StyledTableRow>
          ))}
        </TableBody>
      </Table>
    </TableContainer>
  )
}
