import request from 'ky'
import { UAParser } from 'ua-parser-js'
import $ from 'jquery'
import config from '../../local/js/config'
import { ltikey, ltiurl } from './LTI'

const API_URL = ltiurl()

export default class Api {
  static async log (type, obj) {
    this.parser = new UAParser(navigator.userAgent)
    const ltik = ltikey()
    if (type === 'new_session') {
      if (ltik) {
        const body = {
          type: type,
          device: {
            device_type: this.parser.getDevice().type !== undefined ? this.parser.getDevice().type : 'desktop',
            device_model: this.parser.getDevice().model !== undefined ? this.parser.getDevice().model : 'unknow',
            device_vendor: this.parser.getDevice().vendor !== undefined ? this.parser.getDevice().vendor : 'unknow'
          },
          browser: this.parser.getBrowser().name,
          os: this.parser.getOS()
        }

        await request.post(API_URL + '/event?ltik=' + ltikey(), { json: body, mode: 'cors', credentials: 'include' })

        return true
      } else {
        return false
      }
    } else {
      sessionStorage.getItem(config.ModuleName + '_ltik', ltik)
      const body = {
        type: type,
        device: {
          device_type: this.parser.getDevice().type !== undefined ? this.parser.getDevice().type : 'desktop',
          device_model: this.parser.getDevice().model !== undefined ? this.parser.getDevice().model : 'unknow',
          device_vendor: this.parser.getDevice().vendor !== undefined ? this.parser.getDevice().vendor : 'unknow'
        },
        browser: this.parser.getBrowser().name,
        os: this.parser.getOS(),
        other: obj
      }

      await request.post(API_URL + '/event?ltik=' + ltikey(), { json: body, mode: 'cors', credentials: 'include' })

      return true
    }
  }

  static async sendComment (obj) {
    try {
      await request.post(API_URL + '/comment?ltik=' + ltikey(), { json: obj, mode: 'cors', credentials: 'include' })
      return true
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [comment].'])
      return false
    }
  }

  static async sendHighlight (obj) {
    console.log(obj)
    try {
      await request.post(API_URL + '/highlight?ltik=' + ltikey(), { json: obj, mode: 'cors', credentials: 'include' })
      return true
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [highlight].'])
      return false
    }
  }

  static async getComments () {
    try {
      const response = await request.get(API_URL + '/comment/all?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' }).json()
      return response
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar buscar [comment].'])
      return false
    }
  }

  static async getHighlights () {
    try {
      const response = await request.get(API_URL + '/highlight/all?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' }).json()
      return response
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar buscar [highlight].'])
      return false
    }
  }

  static async getPageInfo () {
    try {
      const response = await request.get(API_URL + '/pageinfo?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' }).json()
      if (response.err) return false
      return response[0].info
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar buscar [pageInfo].'])
      return false
    }
  }

  static async sendPageInfo (obj) {
    try {
      const response = await request.post(API_URL + '/pageinfo?ltik=' + ltikey(), { json: obj, mode: 'cors', credentials: 'include' })
      return response
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [pageInfo].'])
      return false
    }
  }

  static async getFeedback (id) {
    try {
      const response = await request.get(API_URL + '/feedback/' + id + '?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' }).json()
      if (response.err) return false
      return response
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar buscar [feedback].'])
      return false
    }
  }

  static async sendFeedback (id, obj) {
    try {
      const response = await request.post(API_URL + '/feedback/' + id + '?ltik=' + ltikey(), { json: obj, mode: 'cors', credentials: 'include' })
      return response
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [feedback].'])
      return false
    }
  }

  // Delete comment and highlight

  static async deleteComment (id) {
    try {
      await request.delete(API_URL + '/comment/' + id + '?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' })
      return true
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [comment].'])
      return false
    }
  }

  static async deleteHighlight (id) {
    try {
      await request.delete(API_URL + '/highlight/' + id + '?ltik=' + ltikey(), { mode: 'cors', credentials: 'include' })
      return true
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [comment].'])
      return false
    }
  }

  static async updateComment (id, text) {
    try {
      const obj = {
        comment: text
      }
      await request.post(API_URL + '/comment/' + id + '?ltik=' + ltikey(), { json: obj, mode: 'cors', credentials: 'include' })
      return true
    } catch (err) {
      $(document).trigger('errorMessage', ['Erro ao tentar enviar [comment].'])
      return false
    }
  }
}
